@@ -17,7 +17,7 @@ class DingDingPlugin(NotificationPlugin):
     """
     author = 'dreamerldq'
     author_url = 'https://github.com/dreamerldq/sentry-dingding-format'
-    version = '1.0.20'
+    version = '1.0.21'
     description = 'Send project error counts to DingDing .'
     resource_links = [
         ('Source', 'https://github.com/dreamerldq/sentry-dingding-format'),
@@ -43,8 +43,8 @@ class DingDingPlugin(NotificationPlugin):
     def getGroupCount(self, groupId):
         url = 'http://localhost:9000/api/0/issues/{groupId}/'.format(groupId=groupId )
         r = requests.get(url).json()
-        # return r["count"]
-        return 100
+        return r.data["count"]
+        # return 100
 
     def post_process(self, group, event, *args, **kwargs):
         """
